============
Contribute
============

Contributions are very welcome!

Coding Style
----------------------

Please refer to Google coding style guidelines.

Get Involved!
----------------------

Test the project::

    % python setup.py develop

Or run::

    % tox

Submit your patches::

    % git diff
